@@ -89,6 +89,8 @@ class HttpOperator(BaseOperator):
     :param tcp_keep_alive_interval: The TCP Keep Alive interval parameter (corresponds to
         ``socket.TCP_KEEPINTVL``)
     :param deferrable: Run operator in the deferrable mode
+    :param retry_args: Arguments which define the retry behaviour.
+        See Tenacity documentation at https://github.com/jd/tenacity
     """
 
     conn_id_field = "http_conn_id"
@@ -120,6 +122,7 @@ class HttpOperator(BaseOperator):
         tcp_keep_alive_count: int = 20,
         tcp_keep_alive_interval: int = 30,
         deferrable: bool = conf.getboolean("operators", "default_deferrable", fallback=False),
+        retry_args: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
@@ -139,6 +142,7 @@ class HttpOperator(BaseOperator):
         self.tcp_keep_alive_count = tcp_keep_alive_count
         self.tcp_keep_alive_interval = tcp_keep_alive_interval
         self.deferrable = deferrable
+        self.retry_args = retry_args
 
     @property
     def hook(self) -> HttpHook:
@@ -167,7 +171,12 @@ class HttpOperator(BaseOperator):
 
     def execute_sync(self, context: Context) -> Any:
         self.log.info("Calling HTTP method")
-        response = self.hook.run(self.endpoint, self.data, self.headers, self.extra_options)
+        if self.retry_args:
+            response = self.hook.run_with_advanced_retry(
+                self.retry_args, self.endpoint, self.data, self.headers, self.extra_options
+            )
+        else:
+            response = self.hook.run(self.endpoint, self.data, self.headers, self.extra_options)
         response = self.paginate_sync(response=response)
         return self.process_response(context=context, response=response)
 
@@ -180,7 +189,12 @@ class HttpOperator(BaseOperator):
             next_page_params = self.pagination_function(response)
             if not next_page_params:
                 break
-            response = self.hook.run(**self._merge_next_page_parameters(next_page_params))
+            if self.retry_args:
+                response = self.hook.run_with_advanced_retry(
+                    self.retry_args, **self._merge_next_page_parameters(next_page_params)
+                )
+            else:
+                response = self.hook.run(**self._merge_next_page_parameters(next_page_params))
             all_responses.append(response)
         return all_responses
 
